#!/bin/sh
#
# 
# InforSuite
#
# Description:	Manages InforSuite as Linux-HA resource

#
# Author:	CS2C		
# Support:	support@cs2c.com.cn
# License:	GNU General Public License (GPL)
# Copyright:	(C) 2009 CS2C
# For InforSuite version: 8.1
#
# See usage() function below for more details...
#
# OCF instance parameters:
#   OCF_RESKEY_InforSuite_HOME=/opt/CVICSE/InforSuite
#   OCF_RESKEY_port=8080
#   OCF_RESKEY_sleeptime=40
#######################################################################
# Initialization:
OCF_RESKEY_adminiserverip=${2}
OCF_RESKEY_port=${3}

STATE_OK=0
STATE_WARNING=1
STATE_CRITICAL=2
STATE_UNKNOWN=3
STATE_ERR_ARGS=4

CMD=`basename $0`

#######################################################################

usage() {
  cat <<UEND
usage: $CMD monitor adminiserverip port
UEND
}

meta_data() {
	cat <<END
<?xml version="1.0"?>
<!DOCTYPE resource-agent SYSTEM "ra-api-1.dtd">
<resource-agent name="InforSuite">
<version>1.0</version>

<longdesc lang="en">
Resource script for InforSuite. 
It manages InforSuite as an HA resource.
</longdesc>
<shortdesc lang="en">InforSuite resource agent</shortdesc>

<parameters>

<parameter name="InforSuite_HOME" unique="1" required="1">
<longdesc lang="en">
Directory containing InforSuite
</longdesc>
<shortdesc lang="en">InforSuite installdir</shortdesc>
<content type="string" default="/root/CVICSE/InforSuite" />
</parameter>

<parameter name="port" unique="1" required="1">
<longdesc lang="en">
The InforSuite Port.
</longdesc>
<shortdesc lang="en">The InforSuite Port</shortdesc>
<content type="string" default="8080" />
</parameter>

<parameter name="sleeptime" unique="1" required="1">
<longdesc lang="en">
The time star process need to sleep,maybe need change
</longdesc>
<shortdesc lang="en">The time star process need to sleep,maybe need change</shortdesc>
<content type="string" default="35" />
</parameter>
</parameters>

<actions>
<action name="monitor" depth="0" timeout="30" interval="10" start-delay="10" />
<action name="validate-all" timeout="5" />
<action name="meta-data" timeout="5" />
</actions>
</resource-agent>
END
}

InforSuite_monitor() {
    #if [ `ps awx|grep  java|grep -c "com.cvicse.inforsuite.base" | grep -v grep ` -gt 0 ]; then
     if [ `ps awx|grep  java|grep -c "com.cvicse" | grep -v grep ` -gt 0 ]; then

        wget -O- -q -L http://$OCF_RESKEY_adminiserverip:$OCF_RESKEY_port | tr '\012' ' ' | grep -Ei "html" >/dev/null 2>&1
        retval=$?
        if [ $retval -eq 0 ];then         
            #key-key
            echo "OK InforSuite server is running|state=0"
            #echo "service_InforSuite_ok"
	    exit $STATE_OK
        else 
            #key-key
            echo "CRITICAL InforSuite server is error|state=1"
            #echo "service_InforSuite_critical_error "
            exit $STATE_CRITICAL
        fi
    else
        #key-key
        echo "CRITICAL InforSuite server is not running|state=1"
        #echo "service_InforSuite_critical_not_running "
        exit $STATE_CRITICAL
    fi
}

#
#       'main' starts here...
#
# What kind of method was invoked?

if
  ( [ $# -ne 3 ] )
then
  usage
  exit $STATE_ERR_ARGS
fi

case "$1" in

  monitor)	InforSuite_monitor;;

  *)		usage
		exit $OCF_ERR_UNIMPLEMENTED;;
esac
exit $?
