#! /bin/sh
#
# 
# Tomcat 6
#
# Description:	Manages an Tomcat 7 as a NeoShineHA resource
#
# See usage() function below for more details...
#
# OCF instance parameters:
#OCF_RESKEY_domainname=${1}
OCF_RESKEY_adminiserverip=${2}
OCF_RESKEY_port=${3}
OCF_RESKEY_sleeptime=${4}

CMD=`basename $0`

STATE_OK=0
STATE_WARNING=1
STATE_CRITICAL=2
STATE_UNKNOWN=3
STATE_ERR_ARGS=4

# Initialization:

#. ${OCF_ROOT}/resource.d/heartbeat/.ocf-shellfuncs
# Initialization:
#OCF_ROOT=/usr/lib/ocf
#: ${OCF_FUNCTIONS_DIR=${OCF_ROOT}/lib/heartbeat}
#. ${OCF_FUNCTIONS_DIR}/ocf-shellfuncs
#######################################################################

usage() {
  methods=`tomcat_methods`
  methods=`echo $methods | tr ' ' '|'`
  cat <<-!
	usage: $CMD {$methods}

	$CMD monitor an Tomcat 10.3 instance as the system resource.

	The 'monitor' operation reports whether the tomcat seems to be working
	The 'validate-all' operation reports whether the parameters are valid
	The 'methods' operation reports on the methods $CMD supports
	
	usage: check_Tomcat.sh monitor beahome adminiserverip port
	!

}

meta_data() {
	cat <<END
<?xml version="1.0"?>
<!DOCTYPE resource-agent SYSTEM "ra-api-1.dtd">
<resource-agent name="tomcat">
<version>1.0</version>

<longdesc lang="en">
Resource script for Tomcat. Manages an Tomcat 9.2 instance
as an HA resource.
</longdesc>
<shortdesc lang="en">tomcat resource agent</shortdesc>

<parameters>

<parameter name="beahome" unique="1" required="1">
<longdesc lang="en">
The tomcat home directory.
</longdesc>
<shortdesc lang="en">beahome</shortdesc>
<content type="string" default="" />
</parameter>

<parameter name="domainname" unique="1" required="1">
<longdesc lang="en">
The Domanin Name.
</longdesc>
<shortdesc lang="en">domainname</shortdesc>
<content type="string" default="" />
</parameter>

<parameter name="adminiserverip" unique="1" required="1">
<longdesc lang="en">
The Admini Server IP.
</longdesc>
<shortdesc lang="en">Admini Server IP</shortdesc>
<content type="string" default="" />
</parameter>

<parameter name="port" unique="1" required="1">
<longdesc lang="en">
The Admini Server Port.
</longdesc>
<shortdesc lang="en">The Admini Server Port</shortdesc>
<content type="string" default="" />
</parameter>

<parameter name="sleeptime" unique="1" required="1">
<longdesc lang="en">
The time start process need to sleep,maybe need change
</longdesc>
<shortdesc lang="en">The time start process need to sleep,maybe need change</shortdesc>
<content type="string" default="30" />
</parameter>


</parameters>

<actions>
<action name="start" timeout="120" />
<action name="stop" timeout="120" />
<action name="monitor" depth="0" timeout="30" interval="60" start-delay="10" />
<action name="validate-all" timeout="5" />
<action name="meta-data" timeout="5" />
</actions>
</resource-agent>
END
}


#
# methods: What methods/operations do we support?
#
tomcat_methods() {
  cat <<-!
	monitor
	validate-all
	methods
	meta-data
	usage
	!
}


tomcat_start() {
   chk_admini=`ps awx | grep $OCF_RESKEY_domainname/startWebLogic.sh |grep -v 'grep'|wc -l` 

   if [ $chk_admini -eq 1 ]; then 
      echo "Tomcat already running"
      return $OCF_SUCCESS;
   else
      if [ $chk_admini -eq 0 ]; then
    $OCF_RESKEY_beahome/user_projects/domains/$OCF_RESKEY_domainname/startWebLogic.sh >/dev/null 2>&1 & 
      sleep $OCF_RESKEY_sleeptime
      fi

    chk_admini_1=`ps awx | grep $OCF_RESKEY_domainname/startWebLogic.sh |grep -v 'grep'|wc -l`

    if  [ $chk_admini_1 -eq 1 ]; then
	echo "Start Tomcat success"
        return $OCF_SUCCESS
    else
        echo "Start Tomcat error"
        return $OCF_ERR_GENERIC
    fi
fi
}


tomcat_stop() {

   chk_admini=`ps awx | grep $OCF_RESKEY_domainname/startWebLogic.sh |grep -v 'grep'|wc -l`

   if [ $chk_admini -eq 0 ]; then
      echo "Tomcat is not running"
      return $OCF_SUCCESS;
   else
    $OCF_RESKEY_beahome/user_projects/domains/$OCF_RESKEY_domainname/bin/stopWebLogic.sh 
    admini_pid=`ps aux |grep java|grep tomcat.Name=AdminServer |cut -c 10-15`

    if [ !  -z $admini_pid ]; then
      kill -9 $admini_pid 
    fi

    sleep 10

    chk_admini_1=`ps awx | grep $OCF_RESKEY_domainname/startWebLogic.sh |grep -v 'grep'|wc -l`
    
    if  [ $chk_admini_1 -eq 0 ]; then
        echo "Stop Tomcat success"
        return $OCF_SUCCESS
    else
        echo "Stop Tomcat error"
        return $OCF_ERR_GENERIC
    fi
fi
}

tomcat_monitor() {
    /etc/init.d/tomcat6 status >/dev/null 2>&1
    chk_retval=$?

    case "$chk_retval" in
        "0")
            #key-key
            echo "OK Tomcat6 is running|state=0"
            #echo "service_tomcat_ok"
            exit $STATE_OK
      	    ;;
        "1")
            #key-key
            echo "PID file exists, but process is not running|state=1"
            #echo "service_tomcat_critical_error_pidfileexists_not_running "
            exit $STATE_CRITICAL
      	    ;;
        "2")
            #key-key
            echo "tomcat6.pid lockfile exists but process is not running|state=1"
            #echo "service_tomcat_critical_error_lockfileexists_not_running "
            exit $STATE_CRITICAL
      	    ;;
        "3")
            #key-key
            echo "Tomcat6 is stopped|state=1"
            #echo "service_tomcat_critical_not_running "
            exit $STATE_CRITICAL
      	    ;;
    esac
}

tomcat_validate() {
 if [ ! -d $OCF_RESKEY_beahome ]; then
        echo "Tomcat InstallDir $OCF_RESKEY_beahome dosen't exist";
        exit $OCF_ERR_ARGS;
 fi
}

#
#       'main' starts here...
#

if
  ( [ $# -ne 3 ] )
then
  usage
  exit $STATE_ERR_ARGS
fi

case "$1" in

  monitor)	tomcat_validate;
		tomcat_monitor;;

  validate-all)	tomcat_validate; exit $OCF_SUCCESS;;

  meta-data) meta_data; exit $OCF_SUCCESS;;

  *)		usage
		exit $OCF_ERR_UNIMPLEMENTED;;
esac
exit $?
