#!/bin/bash
#
# This shell script takes care of monitoring 
#  the Dameng subsystem.
#
# description: Dameng database server.
# processname: dmServer
# pidfile: /var/run/dmserver.pid
# version: V5.0.0.31

print_usage()
{
    echo "Usage: check_dmdb.sh --status <DMDB installation directory>"
    return 0
}


[ -z "${1:-}" -o -z "${2:-}" ] && print_usage && exit 1

svc_prog=DmServiceDMSERVER
start_type=open
myname=`whoami`
prog=dmserver
if [ `echo ${2:0-1}` = "/" ]; then 
	dm_home=${2%/*}
else
	dm_home=$2
fi
prog_path=$dm_home/bin
DM_INI=$dm_home/data/DAMENG/dm.ini
export LD_LIBRARY_PATH=$dm_home/bin:$LD_LIBRARY_PATH
ulimit -c unlimited
pid_file="${svc_prog}.pid"

# define some functions to be used by most or all shell scripts
# -------------------------------functions start------------------------------

#get the pid count
getpidcount()
{
    ps -eo pid,command | egrep -w "$DM_INI" | grep "$prog_path/$prog" | grep -c $prog
}

#get the pid
getpid() {
    ps -eo pid,command | egrep -w "$DM_INI" |  grep "$prog_path/$prog" | cut -c 1-5
}

# -------------------------------functions end------------------------------
# krms must have execute permission
if [ ! -x "$prog_path/$prog" ]; then
    echo "DMDB Installation directory is invalid"
    exit 1
fi


status() {
   pid=`getpidcount`
   if [ $pid -ge 1 ]; then
       pid=`getpid`
       #key-key
       echo $"${svc_prog} (pid $pid) is running...|state=0"
       #echo "service_dmdb_ok#$pid"
       #return 0
       exit 0
   fi
   # Next try "/var/run/*.pid" files
   if [ -f /var/run/$pid_file ] ; then
       read pid < /var/run/$pid_file
       if [ -n "$pid" ]; then
           #key-key
           echo $"${svc_prog} dead but pid file exists.|state=1"
           #echo "service_dmdb_dead_but_pid_file_exists#$pid_file"
           #return 1
	       exit 1
       fi
   fi
   #key-key
   echo $"${svc_prog} is stopped.|state=1"
   #echo "service_dmdb_stopped"
   #return 3 :now is critical,should be 2
   exit 2
}

# See how we were called.
case "$1" in
  --status)
    status
    ;;
  *)
    print_usage
    exit 1
esac

#exit 0
